@@ -14,22 +14,38 @@ download_metadata <- function(){ # nocov start
 
     # test server connection with github
     metadata_link <- 'https://github.com/ipeaGIT/aopdata/releases/download/v1.0.0/metadata.csv'
-    check_con <- check_connection(metadata_link, silent = TRUE)
+    try( silent = TRUE,
+         check_con <- check_connection(metadata_link, silent = TRUE)
+         )
 
     # if connection with github fails, try connection with ipea
-    if(is.null(check_con) | isFALSE(check_con)){
+    if (is.null(check_con) | isFALSE(check_con)) {
       metadata_link <- 'https://www.ipea.gov.br/geobr/aopdata/metadata/metadata.csv'
-      check_con <- check_connection(metadata_link, silent = FALSE)
+      try( silent = TRUE,
+           check_con <- check_connection(metadata_link, silent = FALSE)
+           )
 
-      if(is.null(check_con) | isFALSE(check_con)){ return(invisible(NULL)) }
+      if (is.null(check_con) | isFALSE(check_con)) { return(invisible(NULL)) }
       }
 
     # download metadata to temp file
-    httr::GET(url= metadata_link, httr::write_disk(tempf, overwrite = TRUE))
+    try( silent = TRUE,
+         httr::GET(url= metadata_link, httr::write_disk(tempf, overwrite = TRUE))
+         )
+
+    # if everything fails, return NULL
+    if (!file.exists(tempf) | file.info(tempf)$size == 0) { return(invisible(NULL)) }
   }
 
  # read metadata
   metadata <- data.table::fread(tempf, stringsAsFactors=FALSE)
+
+  # check if data was read Ok
+  if (nrow(metadata)==0) {
+    message("A file must have been corrupted during download. Please restart your R session and download the data again.")
+    return(invisible(NULL))
+  }
+
   return(metadata)
 
 }  # nocov end
